//@line 36 "/builds/releases/3.0a3/3/l10n/sk/mail/all-l10n.js"

//@line 38 "/builds/releases/3.0a3/3/l10n/sk/mail/all-l10n.js"

pref("general.useragent.locale", "sk");
pref("spellchecker.dictionary", "sk");
